#!/usr/bin/env python
import time
import RPi.GPIO as GPIO


#=====================================
# ziskani namereneho udaje z jednoho kanalu
def adc(kanal, clk_pin, dataout_pin, datain_pin, cs_pin):
  # uvodni nastaveni signalu (pred startem mereni)
  GPIO.output(cs_pin, True)       # CS na "1" obvod neni aktivni
  GPIO.output(clk_pin, False)     # Hodiny do "0"
  GPIO.output(cs_pin, False)      # CS na "0" = obvod aktivovan v rezimu 0.0

  GPIO.output(datain_pin, True)   # "Start" bit do "1" (zacatek komunikace)
  tik_clk(clk_pin)

  GPIO.output(datain_pin, True)   # "Single/Diff" bit do "1" (mereni jednotlivych kanalu)     
  tik_clk(clk_pin)

  # dalsi 3 bity urcuji kanal, ktery bude merit -(0b000 az 0b111). Podle kat. listu maji bity oznaceni D2, D1 a D0
  for i in range (2,-1,-1):
    if (pow(2,i) & kanal == 0):
      GPIO.output(datain_pin, False)  # na prislusne pozici v bitovem oznaceni kanalu je "0"     
    else:
      GPIO.output(datain_pin, True)   # na prislusne pozici v bitovem oznaceni kanalu je "1"  
    tik_clk(clk_pin)                  # po kazdem bitu se tikne hodinami



  # po odeslani prikazu do ADC se precte odpoved (13-bitova hodnota)
  tik_clk(clk_pin)    # prvni bit by mel byt "0", tak se jen odtikne

  digit = 0
  for i in range(12,-1,-1):  # dalsich 12 bitu uz je namerena hodnota  ("i" se meni v intervalu od 11 do 0)
    digit = digit + (GPIO.input(dataout_pin) * pow(2,i))    # postupne nascitani vsech bitu s prislusnou binarni vahou
    tik_clk(clk_pin)                                        # po kazdem bitu se tikne hodinami


  GPIO.output(clk_pin, True)   # na zaver hodiny nastavit na "1"
  GPIO.output(cs_pin, True)    # a deaktivovat cip

  return digit



#=====================================
# jedno tiknuti na hodinovem pinu (z "0" do "1" a hned zpatky na "0")
def tik_clk(clk_pin):
  GPIO.output(clk_pin, True)
  GPIO.output(clk_pin, False)



#=====================================
# prirazeni ridicich pinu ADC na GPIO
GPIO.setmode(GPIO.BCM)   # oznaceni GPIO podle signalu z procesoru
clk_pin = 11       # GPIO11 = PIN23   (hodiny)
dataout_pin = 9    # GPIO9  = PIN21   (data z ADC do RasPi)
datain_pin = 10    # GPIO10 = PIN19   (data z RasPi do ADC)
cs_pin = 27        # GPIO27(rev2) = PIN13 (aktivace ADC - chip select)

# nastaveni smeru komunikace
GPIO.setwarnings(False)
GPIO.setup(dataout_pin, GPIO.IN)   # z pohledu RasPi je to vstup dat z AD prevodniku
GPIO.setup(datain_pin, GPIO.OUT)   # z pohledu RasPi je to vystup dat do AD prevodniku
GPIO.setup(clk_pin, GPIO.OUT)      # hodiny jsou ovladany z RasPi do AD prevodniku
GPIO.setup(cs_pin, GPIO.OUT)       # ChipSelect je take ovladany z RasPi do AD prevodniku


# hlavni merici smycka
while True:

  # meri se vsech 8 kanalu
  for i in range (8):
    print  str(adc(i, clk_pin, dataout_pin, datain_pin, cs_pin)).rjust(4,"0"),
  print ""
  
  time.sleep(1)